<!DOCTYPE html>
<html lang="nl">
	<head><script src="/gdpr/gdprscript.js?buildTime=1677879501&hasRemindMe=true&stealth=false"></script>
		<title>Contact - SUVARNAPHUM</title><meta property="og:site_name" content="SUVARNAPHUM" />
<meta property="og:title" content="Contact" />
<meta property="og:description" content="Suvarnaphum THAI RESTAURANT Johan Huizingalaan 250 1065 JM  Amsterdam (Slotervaart/Overtoomse Veld) Reserveren is alleen telefonisch mogelijk: Tel. 020-617 6620" />
<meta property="og:image" content="http://suvarnaphum.nl/uploads/1/2/6/3/126368143/google-maps_orig.jpg" />
<meta property="og:url" content="http://suvarnaphum.nl/contact.html" />

<link rel="icon" type="image/png" href="//www.weebly.com/uploads/reseller/assets/1014-favicon.ico" />



<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
  <meta name="viewport" content="width=device-width, initial-scale=1.0" />

		
		<link id="wsite-base-style" rel="stylesheet" type="text/css" href="//cdn2.editmysite.com/css/sites.css?buildTime=1677879501" />
<link rel="stylesheet" type="text/css" href="//cdn2.editmysite.com/css/old/fancybox.css?1667503124" />
<link rel="stylesheet" type="text/css" href="//cdn2.editmysite.com/css/social-icons.css?buildtime=1667503124" media="screen,projection" />
<link rel="stylesheet" type="text/css" href="/files/main_style.css?1667826869" title="wsite-theme-css" />
<link href='//cdn2.editmysite.com/fonts/Montserrat/font.css?2' rel='stylesheet' type='text/css' />

<style type='text/css'>
.wsite-elements.wsite-not-footer:not(.wsite-header-elements) div.paragraph, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) p, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-block .product-title, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-description, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .wsite-form-field label, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .wsite-form-field label, #wsite-content div.paragraph, #wsite-content p, #wsite-content .product-block .product-title, #wsite-content .product-description, #wsite-content .wsite-form-field label, #wsite-content .wsite-form-field label, .blog-sidebar div.paragraph, .blog-sidebar p, .blog-sidebar .wsite-form-field label, .blog-sidebar .wsite-form-field label {}
#wsite-content div.paragraph, #wsite-content p, #wsite-content .product-block .product-title, #wsite-content .product-description, #wsite-content .wsite-form-field label, #wsite-content .wsite-form-field label, .blog-sidebar div.paragraph, .blog-sidebar p, .blog-sidebar .wsite-form-field label, .blog-sidebar .wsite-form-field label {}
.wsite-elements.wsite-footer div.paragraph, .wsite-elements.wsite-footer p, .wsite-elements.wsite-footer .product-block .product-title, .wsite-elements.wsite-footer .product-description, .wsite-elements.wsite-footer .wsite-form-field label, .wsite-elements.wsite-footer .wsite-form-field label{}
.wsite-elements.wsite-not-footer:not(.wsite-header-elements) h2, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-long .product-title, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-large .product-title, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-small .product-title, #wsite-content h2, #wsite-content .product-long .product-title, #wsite-content .product-large .product-title, #wsite-content .product-small .product-title, .blog-sidebar h2 {}
#wsite-content h2, #wsite-content .product-long .product-title, #wsite-content .product-large .product-title, #wsite-content .product-small .product-title, .blog-sidebar h2 {}
.wsite-elements.wsite-footer h2, .wsite-elements.wsite-footer .product-long .product-title, .wsite-elements.wsite-footer .product-large .product-title, .wsite-elements.wsite-footer .product-small .product-title{}
#wsite-title {color:#8b7671 !important;}
.wsite-menu-default a {}
.wsite-menu a {}
.wsite-image div, .wsite-caption {}
.galleryCaptionInnerText {}
.fancybox-title {}
.wslide-caption-text {}
.wsite-phone {}
.wsite-headline,.wsite-header-section .wsite-content-title {}
.wsite-headline-paragraph,.wsite-header-section .paragraph {}
.wsite-button-inner {}
.wsite-not-footer blockquote {}
.wsite-footer blockquote {}
.blog-header h2 a {}
#wsite-content h2.wsite-product-title {}
.wsite-product .wsite-product-price a {}
@media screen and (min-width: 767px) {.wsite-elements.wsite-not-footer:not(.wsite-header-elements) div.paragraph, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) p, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-block .product-title, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-description, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .wsite-form-field label, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .wsite-form-field label, #wsite-content div.paragraph, #wsite-content p, #wsite-content .product-block .product-title, #wsite-content .product-description, #wsite-content .wsite-form-field label, #wsite-content .wsite-form-field label, .blog-sidebar div.paragraph, .blog-sidebar p, .blog-sidebar .wsite-form-field label, .blog-sidebar .wsite-form-field label {font-size:16px !important;}
#wsite-content div.paragraph, #wsite-content p, #wsite-content .product-block .product-title, #wsite-content .product-description, #wsite-content .wsite-form-field label, #wsite-content .wsite-form-field label, .blog-sidebar div.paragraph, .blog-sidebar p, .blog-sidebar .wsite-form-field label, .blog-sidebar .wsite-form-field label {}
.wsite-elements.wsite-footer div.paragraph, .wsite-elements.wsite-footer p, .wsite-elements.wsite-footer .product-block .product-title, .wsite-elements.wsite-footer .product-description, .wsite-elements.wsite-footer .wsite-form-field label, .wsite-elements.wsite-footer .wsite-form-field label{}
.wsite-elements.wsite-not-footer:not(.wsite-header-elements) h2, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-long .product-title, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-large .product-title, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-small .product-title, #wsite-content h2, #wsite-content .product-long .product-title, #wsite-content .product-large .product-title, #wsite-content .product-small .product-title, .blog-sidebar h2 {}
#wsite-content h2, #wsite-content .product-long .product-title, #wsite-content .product-large .product-title, #wsite-content .product-small .product-title, .blog-sidebar h2 {}
.wsite-elements.wsite-footer h2, .wsite-elements.wsite-footer .product-long .product-title, .wsite-elements.wsite-footer .product-large .product-title, .wsite-elements.wsite-footer .product-small .product-title{}
#wsite-title {}
.wsite-menu-default a {}
.wsite-menu a {}
.wsite-image div, .wsite-caption {}
.galleryCaptionInnerText {}
.fancybox-title {}
.wslide-caption-text {}
.wsite-phone {}
.wsite-headline,.wsite-header-section .wsite-content-title {}
.wsite-headline-paragraph,.wsite-header-section .paragraph {}
.wsite-button-inner {}
.wsite-not-footer blockquote {}
.wsite-footer blockquote {}
.blog-header h2 a {}
#wsite-content h2.wsite-product-title {}
.wsite-product .wsite-product-price a {}
}</style>

		<script>
var STATIC_BASE = '//cdn1.editmysite.com/';
var ASSETS_BASE = '//cdn2.editmysite.com/';
var STYLE_PREFIX = 'wsite';
</script>
<script src='https://cdn2.editmysite.com/js/jquery-1.8.3.min.js'></script>

<script type="text/javascript" src="//cdn2.editmysite.com/js/lang/nl/stl.js?buildTime=1667503124&"></script>
<script src="//cdn2.editmysite.com/js/site/main.js?buildTime=1677879501"></script><script type="text/javascript">
		function initCustomerAccountsModels() {
					(function(){_W.setup_rpc({"url":"\/ajax\/api\/JsonRPC\/CustomerAccounts\/","actions":{"CustomerAccounts":[{"name":"login","len":2,"multiple":false,"standalone":false},{"name":"logout","len":0,"multiple":false,"standalone":false},{"name":"getSessionDetails","len":0,"multiple":false,"standalone":false},{"name":"getAccountDetails","len":0,"multiple":false,"standalone":false},{"name":"getOrders","len":0,"multiple":false,"standalone":false},{"name":"register","len":4,"multiple":false,"standalone":false},{"name":"emailExists","len":1,"multiple":false,"standalone":false},{"name":"passwordReset","len":1,"multiple":false,"standalone":false},{"name":"passwordUpdate","len":3,"multiple":false,"standalone":false},{"name":"validateSession","len":1,"multiple":false,"standalone":false}]},"namespace":"_W.CustomerAccounts.RPC"});
_W.setup_model_rpc({"rpc_namespace":"_W.CustomerAccounts.RPC","model_namespace":"_W.CustomerAccounts.BackboneModelData","collection_namespace":"_W.CustomerAccounts.BackboneCollectionData","bootstrap_namespace":"_W.CustomerAccounts.BackboneBootstrap","models":{"CustomerAccounts":{"_class":"CustomerAccounts.Model.CustomerAccounts","defaults":null,"validation":null,"types":null,"idAttribute":null,"keydefs":null}},"collections":{"CustomerAccounts":{"_class":"CustomerAccounts.Collection.CustomerAccounts"}},"bootstrap":[]});
})();
		}
		if(document.createEvent && document.addEventListener) {
			var initEvt = document.createEvent('Event');
			initEvt.initEvent('customerAccountsModelsInitialized', true, false);
			document.dispatchEvent(initEvt);
		} else if(document.documentElement.initCustomerAccountsModels === 0){
			document.documentElement.initCustomerAccountsModels++
		}
		</script>
		<script type="text/javascript"> _W = _W || {}; _W.securePrefix='api.weeblycloud.com'; </script><script>_W = _W || {};
			_W.customerLocale = "en_US";
			_W.storeName = null;
			_W.isCheckoutReskin = false;
			_W.storeCountry = "NL";
			_W.storeCurrency = "EUR";
			_W.storeEuPrivacyPolicyUrl = "";
			com_currentSite = "856939515511031515";
			com_userID = "126368143";</script><script type="text/javascript">_W.resellerSite = true;</script><script type="text/javascript">_W.configDomain = "www.weebly.com";</script><script>_W.relinquish && _W.relinquish()</script>
<script type="text/javascript" src="//cdn2.editmysite.com/js/lang/nl/stl.js?buildTime=1677879501&"></script><script> _W.themePlugins = [];</script><script type="text/javascript"> _W.recaptchaUrl = "https://www.google.com/recaptcha/api.js"; </script><script type="text/javascript"><!--
	
	
	function initFlyouts(){
		initPublishedFlyoutMenus(
			[{"id":"313224892324534747","title":"Home","url":"index.html","target":"","nav_menu":false,"nonclickable":false},{"id":"355156789405947171","title":"Impressie","url":"impressie.html","target":"","nav_menu":false,"nonclickable":false},{"id":"959743226448925172","title":"Menu","url":"menu.html","target":"","nav_menu":false,"nonclickable":false},{"id":"914030071162666230","title":"Contact","url":"contact.html","target":"","nav_menu":false,"nonclickable":false}],
			"914030071162666230",
			'',
			'active',
			false,
			{"navigation\/item":"<li {{#id}}id=\"{{id}}\"{{\/id}} class=\"wsite-menu-item-wrap\">\n\t<a\n\t\t{{^nonclickable}}\n\t\t\t{{^nav_menu}}\n\t\t\t\thref=\"{{url}}\"\n\t\t\t{{\/nav_menu}}\n\t\t{{\/nonclickable}}\n\t\t{{#target}}\n\t\t\ttarget=\"{{target}}\"\n\t\t{{\/target}}\n\t\t{{#membership_required}}\n\t\t\tdata-membership-required=\"{{.}}\"\n\t\t{{\/membership_required}}\n\t\tclass=\"wsite-menu-item\"\n\t\t>\n\t\t{{{title_html}}}\n\t<\/a>\n\t{{#has_children}}{{> navigation\/flyout\/list}}{{\/has_children}}\n<\/li>\n","navigation\/flyout\/list":"<div class=\"wsite-menu-wrap\" style=\"display:none\">\n\t<ul class=\"wsite-menu\">\n\t\t{{#children}}{{> navigation\/flyout\/item}}{{\/children}}\n\t<\/ul>\n<\/div>\n","navigation\/flyout\/item":"<li {{#id}}id=\"{{id}}\"{{\/id}}\n\tclass=\"wsite-menu-subitem-wrap {{#is_current}}wsite-nav-current{{\/is_current}}\"\n\t>\n\t<a\n\t\t{{^nonclickable}}\n\t\t\t{{^nav_menu}}\n\t\t\t\thref=\"{{url}}\"\n\t\t\t{{\/nav_menu}}\n\t\t{{\/nonclickable}}\n\t\t{{#target}}\n\t\t\ttarget=\"{{target}}\"\n\t\t{{\/target}}\n\t\tclass=\"wsite-menu-subitem\"\n\t\t>\n\t\t<span class=\"wsite-menu-title\">\n\t\t\t{{{title_html}}}\n\t\t<\/span>{{#has_children}}<span class=\"wsite-menu-arrow\">&gt;<\/span>{{\/has_children}}\n\t<\/a>\n\t{{#has_children}}{{> navigation\/flyout\/list}}{{\/has_children}}\n<\/li>\n"},
			{}
		)
	}
//-->
</script>
		
		
	</head>
	<body class="header-page  wsite-page-contact  full-width-body-off header-overlay-on alt-nav-off  wsite-theme-light"><div class="wrapper">
    <div class="birdseye-header">
      <div class="nav-wrap">
        <div class="container">
          <div class="logo"><span class="wsite-logo">

	<a href="/">
	
	<span id="wsite-title">SUVARNAPHUM</span>
	
	</a>

</span></div>
          <div class="nav desktop-nav"><ul class="wsite-menu-default">
		<li id="pg313224892324534747" class="wsite-menu-item-wrap">
			<a
						href="/"
				class="wsite-menu-item"
				>
				Home
			</a>
			
		</li>
		<li id="pg355156789405947171" class="wsite-menu-item-wrap">
			<a
						href="/impressie.html"
				class="wsite-menu-item"
				>
				Impressie
			</a>
			
		</li>
		<li id="pg959743226448925172" class="wsite-menu-item-wrap">
			<a
						href="/menu.html"
				class="wsite-menu-item"
				>
				Menu
			</a>
			
		</li>
		<li id="active" class="wsite-menu-item-wrap">
			<a
						href="/contact.html"
				class="wsite-menu-item"
				>
				Contact
			</a>
			
		</li>
</ul>
</div>
          <a class="hamburger" aria-label="Menu" href="#"><span></span></a>
        </div>
      </div>
    </div>

    <div class="banner-wrap">
      <div class="wsite-elements wsite-not-footer wsite-header-elements">
	<div class="wsite-section-wrap">
	<div  class="wsite-section wsite-header-section wsite-section-bg-image" style="height: auto;background-image: url(&quot;/uploads/1/2/6/3/126368143/background-images/1547033650.jpg&quot;) ;background-repeat: no-repeat ;background-position: 50% 50% ;background-size: 100% ;background-color: transparent ;background-size: cover;" >
		<div class="wsite-section-content">
			
          <div class="container">
            <div class="banner">
				<div class="wsite-section-elements">
					
				</div>
			</div>
          </div>
      
		</div>
		<div class=""></div>
	</div>
</div>

</div>

    </div>

    <div class="main-wrap">
      <div id="wsite-content" class="wsite-elements wsite-not-footer">
	<div class="wsite-section-wrap">
	<div class="wsite-section wsite-body-section wsite-section-bg-color wsite-background-8" style="height: auto;background-color: #FFFFFF;background-image: none;is_customized: 1;" >
		<div class="wsite-section-content">
          <div class="container">
			<div class="wsite-section-elements">
				<div><div class="wsite-multicol"><div class="wsite-multicol-table-wrap" style="margin:0 -15px;">
	<table class="wsite-multicol-table">
		<tbody class="wsite-multicol-tbody">
			<tr class="wsite-multicol-tr">
				<td class="wsite-multicol-col" style="width:43.850267379679%; padding:0 15px;">
					
						

<div class="paragraph">Suvarnaphum<br />THAI RESTAURANT<br />Johan Huizingalaan 250<br />1065 JM&nbsp; Amsterdam<br />(Slotervaart/Overtoomse Veld)<br /><br /><strong>Reserveren is alleen telefonisch mogelijk: Tel. </strong><a href="tel:0206176620%20">020-617 6620</a><br /></div>


					
				</td>				<td class="wsite-multicol-col" style="width:56.149732620321%; padding:0 15px;">
					
						

<div class="paragraph">Maandag gesloten.<br />Dinsdag t/m zondag is de keuken open van 16:00 tot 22:00 uur.<br /><br />Ons restaurant heeft plaats voor maximaal 26 personen.<br />Bij grote groepen gelieve van te voren reserveren.<br /><br />Afhalen is ook mogelijk.<br /><br /></div>


					
				</td>			</tr>
		</tbody>
	</table>
</div></div></div>

<div><div class="wsite-image wsite-image-border-none " style="padding-top:10px;padding-bottom:10px;margin-left:0px;margin-right:0px;text-align:center">
<a href='https://www.google.nl/maps/place/Thais+restaurant+Suvarnaphum/@52.3535642,4.8204537,15z/data=!4m5!3m4!1s0x47c5e225ed9881a7:0x96392ab193c20463!8m2!3d52.3545886!4d4.8269769' target='_blank'>
<img src="/uploads/1/2/6/3/126368143/google-maps_orig.jpg" alt="Foto" style="width:auto;max-width:100%" />
</a>
<div style="display:block;font-size:90%"></div>
</div></div>

<div class="wsite-spacer" style="height:50px;"></div>
			</div>
		</div>
      </div>

	</div>
</div>

</div>

    </div>

    <div class="footer-wrap">
        <div class="footer"><div class='wsite-elements wsite-footer'>Site powered by Weebly. Managed by <a href="https://www.hostmonster.com" target="_blank" rel="nofollow">Hostmonster</a></div></div>
    </div><!-- end footer-wrap -->
  </div><!-- /.wrapper -->

  <div id="navMobile" class="nav mobile-nav">
    <a class="hamburger" aria-label="Menu" href="#"><span></span></a>
    <ul class="wsite-menu-default">
    		<li id="pg313224892324534747" class="wsite-menu-item-wrap">
    			<a
    						href="/"
    				class="wsite-menu-item"
    				>
    				Home
    			</a>
    			
    		</li>
    		<li id="pg355156789405947171" class="wsite-menu-item-wrap">
    			<a
    						href="/impressie.html"
    				class="wsite-menu-item"
    				>
    				Impressie
    			</a>
    			
    		</li>
    		<li id="pg959743226448925172" class="wsite-menu-item-wrap">
    			<a
    						href="/menu.html"
    				class="wsite-menu-item"
    				>
    				Menu
    			</a>
    			
    		</li>
    		<li id="active" class="wsite-menu-item-wrap">
    			<a
    						href="/contact.html"
    				class="wsite-menu-item"
    				>
    				Contact
    			</a>
    			
    		</li>
    </ul>
  </div>

	<script type="text/javascript" src="/files/theme/plugins.js?1565969634"></script>
  <script type="text/javascript" src="/files/theme/custom.js?1565969634"></script>
    <div id="customer-accounts-app"></div>
    <script src="//cdn2.editmysite.com/js/site/main-customer-accounts-site.js?buildTime=1677879501"></script>

		

	</body>
</html>
