<!DOCTYPE html>
<html lang="nl">
	<head><script src="/gdpr/gdprscript.js?buildTime=1680891770&hasRemindMe=true&stealth=false"></script>
		<title>SUVARNAPHUM - Home</title><meta property="og:site_name" content="SUVARNAPHUM" />
<meta property="og:title" content="SUVARNAPHUM" />
<meta property="og:description" content="​Welkom bij Suvarnaphum Restaurant. Wij zijn gevestigd op de Johan Huizingalaan nummer 250 te Amsterdam, waar wij zes dagen per week met passie onze gasten verwennen met authentiek Thaise..." />
<meta property="og:image" content="http://suvarnaphum.nl/uploads/1/2/6/3/126368143/boeddha_1_orig.jpg" />
<meta property="og:url" content="http://suvarnaphum.nl/" />

<link rel="icon" type="image/png" href="//www.weebly.com/uploads/reseller/assets/1014-favicon.ico" />



<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
  <meta name="viewport" content="width=device-width, initial-scale=1.0" />

		
		<link id="wsite-base-style" rel="stylesheet" type="text/css" href="//cdn2.editmysite.com/css/sites.css?buildTime=1680891770" />
<link rel="stylesheet" type="text/css" href="//cdn2.editmysite.com/css/old/fancybox.css?1680891770" />
<link rel="stylesheet" type="text/css" href="//cdn2.editmysite.com/css/social-icons.css?buildtime=1680891770" media="screen,projection" />
<link rel="stylesheet" type="text/css" href="/files/main_style.css?1681155638" title="wsite-theme-css" />
<link href='//cdn2.editmysite.com/fonts/Montserrat/font.css?2' rel='stylesheet' type='text/css' />

<style type='text/css'>
.wsite-elements.wsite-not-footer:not(.wsite-header-elements) div.paragraph, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) p, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-block .product-title, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-description, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .wsite-form-field label, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .wsite-form-field label, #wsite-content div.paragraph, #wsite-content p, #wsite-content .product-block .product-title, #wsite-content .product-description, #wsite-content .wsite-form-field label, #wsite-content .wsite-form-field label, .blog-sidebar div.paragraph, .blog-sidebar p, .blog-sidebar .wsite-form-field label, .blog-sidebar .wsite-form-field label {}
#wsite-content div.paragraph, #wsite-content p, #wsite-content .product-block .product-title, #wsite-content .product-description, #wsite-content .wsite-form-field label, #wsite-content .wsite-form-field label, .blog-sidebar div.paragraph, .blog-sidebar p, .blog-sidebar .wsite-form-field label, .blog-sidebar .wsite-form-field label {}
.wsite-elements.wsite-footer div.paragraph, .wsite-elements.wsite-footer p, .wsite-elements.wsite-footer .product-block .product-title, .wsite-elements.wsite-footer .product-description, .wsite-elements.wsite-footer .wsite-form-field label, .wsite-elements.wsite-footer .wsite-form-field label{}
.wsite-elements.wsite-not-footer:not(.wsite-header-elements) h2, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-long .product-title, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-large .product-title, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-small .product-title, #wsite-content h2, #wsite-content .product-long .product-title, #wsite-content .product-large .product-title, #wsite-content .product-small .product-title, .blog-sidebar h2 {}
#wsite-content h2, #wsite-content .product-long .product-title, #wsite-content .product-large .product-title, #wsite-content .product-small .product-title, .blog-sidebar h2 {}
.wsite-elements.wsite-footer h2, .wsite-elements.wsite-footer .product-long .product-title, .wsite-elements.wsite-footer .product-large .product-title, .wsite-elements.wsite-footer .product-small .product-title{}
#wsite-title {color:#8b7671 !important;}
.wsite-menu-default a {}
.wsite-menu a {}
.wsite-image div, .wsite-caption {}
.galleryCaptionInnerText {}
.fancybox-title {}
.wslide-caption-text {}
.wsite-phone {}
.wsite-headline,.wsite-header-section .wsite-content-title {}
.wsite-headline-paragraph,.wsite-header-section .paragraph {}
.wsite-button-inner {}
.wsite-not-footer blockquote {}
.wsite-footer blockquote {}
.blog-header h2 a {}
#wsite-content h2.wsite-product-title {}
.wsite-product .wsite-product-price a {}
@media screen and (min-width: 767px) {.wsite-elements.wsite-not-footer:not(.wsite-header-elements) div.paragraph, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) p, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-block .product-title, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-description, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .wsite-form-field label, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .wsite-form-field label, #wsite-content div.paragraph, #wsite-content p, #wsite-content .product-block .product-title, #wsite-content .product-description, #wsite-content .wsite-form-field label, #wsite-content .wsite-form-field label, .blog-sidebar div.paragraph, .blog-sidebar p, .blog-sidebar .wsite-form-field label, .blog-sidebar .wsite-form-field label {font-size:16px !important;}
#wsite-content div.paragraph, #wsite-content p, #wsite-content .product-block .product-title, #wsite-content .product-description, #wsite-content .wsite-form-field label, #wsite-content .wsite-form-field label, .blog-sidebar div.paragraph, .blog-sidebar p, .blog-sidebar .wsite-form-field label, .blog-sidebar .wsite-form-field label {}
.wsite-elements.wsite-footer div.paragraph, .wsite-elements.wsite-footer p, .wsite-elements.wsite-footer .product-block .product-title, .wsite-elements.wsite-footer .product-description, .wsite-elements.wsite-footer .wsite-form-field label, .wsite-elements.wsite-footer .wsite-form-field label{}
.wsite-elements.wsite-not-footer:not(.wsite-header-elements) h2, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-long .product-title, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-large .product-title, .wsite-elements.wsite-not-footer:not(.wsite-header-elements) .product-small .product-title, #wsite-content h2, #wsite-content .product-long .product-title, #wsite-content .product-large .product-title, #wsite-content .product-small .product-title, .blog-sidebar h2 {}
#wsite-content h2, #wsite-content .product-long .product-title, #wsite-content .product-large .product-title, #wsite-content .product-small .product-title, .blog-sidebar h2 {}
.wsite-elements.wsite-footer h2, .wsite-elements.wsite-footer .product-long .product-title, .wsite-elements.wsite-footer .product-large .product-title, .wsite-elements.wsite-footer .product-small .product-title{}
#wsite-title {}
.wsite-menu-default a {}
.wsite-menu a {}
.wsite-image div, .wsite-caption {}
.galleryCaptionInnerText {}
.fancybox-title {}
.wslide-caption-text {}
.wsite-phone {}
.wsite-headline,.wsite-header-section .wsite-content-title {}
.wsite-headline-paragraph,.wsite-header-section .paragraph {}
.wsite-button-inner {}
.wsite-not-footer blockquote {}
.wsite-footer blockquote {}
.blog-header h2 a {}
#wsite-content h2.wsite-product-title {}
.wsite-product .wsite-product-price a {}
}</style>

		<script>
var STATIC_BASE = '//cdn1.editmysite.com/';
var ASSETS_BASE = '//cdn2.editmysite.com/';
var STYLE_PREFIX = 'wsite';
</script>
<script src='https://cdn2.editmysite.com/js/jquery-1.8.3.min.js'></script>

<script type="text/javascript" src="//cdn2.editmysite.com/js/lang/nl/stl.js?buildTime=1680891770&"></script>
<script src="//cdn2.editmysite.com/js/site/main.js?buildTime=1680891770"></script><script type="text/javascript">
		function initCustomerAccountsModels() {
					(function(){_W.setup_rpc({"url":"\/ajax\/api\/JsonRPC\/CustomerAccounts\/","actions":{"CustomerAccounts":[{"name":"login","len":2,"multiple":false,"standalone":false},{"name":"logout","len":0,"multiple":false,"standalone":false},{"name":"getSessionDetails","len":0,"multiple":false,"standalone":false},{"name":"getAccountDetails","len":0,"multiple":false,"standalone":false},{"name":"getOrders","len":0,"multiple":false,"standalone":false},{"name":"register","len":4,"multiple":false,"standalone":false},{"name":"emailExists","len":1,"multiple":false,"standalone":false},{"name":"passwordReset","len":1,"multiple":false,"standalone":false},{"name":"passwordUpdate","len":3,"multiple":false,"standalone":false},{"name":"validateSession","len":1,"multiple":false,"standalone":false}]},"namespace":"_W.CustomerAccounts.RPC"});
_W.setup_model_rpc({"rpc_namespace":"_W.CustomerAccounts.RPC","model_namespace":"_W.CustomerAccounts.BackboneModelData","collection_namespace":"_W.CustomerAccounts.BackboneCollectionData","bootstrap_namespace":"_W.CustomerAccounts.BackboneBootstrap","models":{"CustomerAccounts":{"_class":"CustomerAccounts.Model.CustomerAccounts","defaults":null,"validation":null,"types":null,"idAttribute":null,"keydefs":null}},"collections":{"CustomerAccounts":{"_class":"CustomerAccounts.Collection.CustomerAccounts"}},"bootstrap":[]});
})();
		}
		if(document.createEvent && document.addEventListener) {
			var initEvt = document.createEvent('Event');
			initEvt.initEvent('customerAccountsModelsInitialized', true, false);
			document.dispatchEvent(initEvt);
		} else if(document.documentElement.initCustomerAccountsModels === 0){
			document.documentElement.initCustomerAccountsModels++
		}
		</script>
		<script type="text/javascript"> _W = _W || {}; _W.securePrefix='bluehost.weeblycloud.com'; </script><script>_W = _W || {};
			_W.customerLocale = "en_US";
			_W.storeName = null;
			_W.isCheckoutReskin = false;
			_W.storeCountry = "NL";
			_W.storeCurrency = "EUR";
			_W.storeEuPrivacyPolicyUrl = "";
			com_currentSite = "856939515511031515";
			com_userID = "126368143";</script><script type="text/javascript">_W.resellerSite = true;</script><script type="text/javascript">_W.configDomain = "www.weebly.com";</script><script>_W.relinquish && _W.relinquish()</script>
<script type="text/javascript" src="//cdn2.editmysite.com/js/lang/nl/stl.js?buildTime=1680891770&"></script><script> _W.themePlugins = [];</script><script type="text/javascript"> _W.recaptchaUrl = "https://www.google.com/recaptcha/api.js"; </script><script type="text/javascript"><!--
	
	
	function initFlyouts(){
		initPublishedFlyoutMenus(
			[{"id":"313224892324534747","title":"Home","url":"index.html","target":"","nav_menu":false,"nonclickable":false},{"id":"355156789405947171","title":"Impressie","url":"impressie.html","target":"","nav_menu":false,"nonclickable":false},{"id":"959743226448925172","title":"Menu","url":"menu.html","target":"","nav_menu":false,"nonclickable":false},{"id":"914030071162666230","title":"Contact","url":"contact.html","target":"","nav_menu":false,"nonclickable":false}],
			"313224892324534747",
			'',
			'active',
			false,
			{"navigation\/item":"<li {{#id}}id=\"{{id}}\"{{\/id}} class=\"wsite-menu-item-wrap\">\n\t<a\n\t\t{{^nonclickable}}\n\t\t\t{{^nav_menu}}\n\t\t\t\thref=\"{{url}}\"\n\t\t\t{{\/nav_menu}}\n\t\t{{\/nonclickable}}\n\t\t{{#target}}\n\t\t\ttarget=\"{{target}}\"\n\t\t{{\/target}}\n\t\t{{#membership_required}}\n\t\t\tdata-membership-required=\"{{.}}\"\n\t\t{{\/membership_required}}\n\t\tclass=\"wsite-menu-item\"\n\t\t>\n\t\t{{{title_html}}}\n\t<\/a>\n\t{{#has_children}}{{> navigation\/flyout\/list}}{{\/has_children}}\n<\/li>\n","navigation\/flyout\/list":"<div class=\"wsite-menu-wrap\" style=\"display:none\">\n\t<ul class=\"wsite-menu\">\n\t\t{{#children}}{{> navigation\/flyout\/item}}{{\/children}}\n\t<\/ul>\n<\/div>\n","navigation\/flyout\/item":"<li {{#id}}id=\"{{id}}\"{{\/id}}\n\tclass=\"wsite-menu-subitem-wrap {{#is_current}}wsite-nav-current{{\/is_current}}\"\n\t>\n\t<a\n\t\t{{^nonclickable}}\n\t\t\t{{^nav_menu}}\n\t\t\t\thref=\"{{url}}\"\n\t\t\t{{\/nav_menu}}\n\t\t{{\/nonclickable}}\n\t\t{{#target}}\n\t\t\ttarget=\"{{target}}\"\n\t\t{{\/target}}\n\t\tclass=\"wsite-menu-subitem\"\n\t\t>\n\t\t<span class=\"wsite-menu-title\">\n\t\t\t{{{title_html}}}\n\t\t<\/span>{{#has_children}}<span class=\"wsite-menu-arrow\">&gt;<\/span>{{\/has_children}}\n\t<\/a>\n\t{{#has_children}}{{> navigation\/flyout\/list}}{{\/has_children}}\n<\/li>\n"},
			{}
		)
	}
//-->
</script>
		
		
	</head>
	<body class="header-page  wsite-page-index  full-width-body-off header-overlay-on alt-nav-off  wsite-theme-light"><div class="wrapper">
    <div class="birdseye-header">
      <div class="nav-wrap">
        <div class="container">
          <div class="logo"><span class="wsite-logo">

	<a href="/">
	
	<span id="wsite-title">SUVARNAPHUM</span>
	
	</a>

</span></div>
          <div class="nav desktop-nav"><ul class="wsite-menu-default">
		<li id="active" class="wsite-menu-item-wrap">
			<a
						href="/"
				class="wsite-menu-item"
				>
				Home
			</a>
			
		</li>
		<li id="pg355156789405947171" class="wsite-menu-item-wrap">
			<a
						href="/impressie.html"
				class="wsite-menu-item"
				>
				Impressie
			</a>
			
		</li>
		<li id="pg959743226448925172" class="wsite-menu-item-wrap">
			<a
						href="/menu.html"
				class="wsite-menu-item"
				>
				Menu
			</a>
			
		</li>
		<li id="pg914030071162666230" class="wsite-menu-item-wrap">
			<a
						href="/contact.html"
				class="wsite-menu-item"
				>
				Contact
			</a>
			
		</li>
</ul>
</div>
          <a class="hamburger" aria-label="Menu" href="#"><span></span></a>
        </div>
      </div>
    </div>

    <div class="banner-wrap">
      <div class="wsite-elements wsite-not-footer wsite-header-elements">
	<div class="wsite-section-wrap">
	<div  class="wsite-section wsite-header-section wsite-section-bg-image wsite-section-effect-reveal" style="height: 630px;vertical-align: middle;background-image: url(&quot;/uploads/1/2/6/3/126368143/background-images/357763433.jpg&quot;) ;background-repeat: no-repeat ;background-position: undefined undefined ;background-size: 100% ;background-color: transparent ;background-size: cover;" >
		<div class="wsite-section-content">
			
          <div class="container">
            <div class="banner">
				<div class="wsite-section-elements">
					<div class="paragraph"><font size="5">&nbsp;</font><br /></div>
				</div>
			</div>
          </div>
      
		</div>
		<div class=""></div>
	</div>
</div>

</div>

    </div>

    <div class="main-wrap">
      <div id="wsite-content" class="wsite-elements wsite-not-footer">
	<div class="wsite-section-wrap">
	<div class="wsite-section wsite-body-section wsite-section-bg-color wsite-background-1" style="height: 661px;background-color: #F5F3F1;background-image: none;is_customized: 1;" >
		<div class="wsite-section-content">
          <div class="container">
			<div class="wsite-section-elements">
				<div><div class="wsite-multicol"><div class="wsite-multicol-table-wrap" style="margin:0 -15px;">
	<table class="wsite-multicol-table">
		<tbody class="wsite-multicol-tbody">
			<tr class="wsite-multicol-tr">
				<td class="wsite-multicol-col" style="width:56.383970177074%; padding:0 15px;">
					
						

<h2 class="wsite-content-title"><font color="#8b7671" size="3"><font size="2">Over ons</font></font><br /></h2>

<div class="paragraph">&#8203;Welkom bij Suvarnaphum Restaurant. Wij zijn gevestigd op de Johan Huizingalaan nummer 250 te Amsterdam, waar wij zes dagen per week met passie onze gasten verwennen met authentiek Thaise gerechten.<br /><br />Wij serveren met veel passie Thaise gerechten. Deze worden bereid met verse producten en alleen de allerbeste ingredi&euml;nten. Hierbij is er een brede keuze aan Thaise voor- en hoofdgerechten.<br />Thais eten staat bekend om haar pittige karakter. Verse pepers maken de gerechten tot een originele smaakbeleving, maar ook zonder de pittigheid beloven de gerechten een ware beleving. Vooraf kunnen alle wensen ten aanzien van de smaak dan ook worden doorgegeven. Er kan rekening gehouden worden per gerecht, waarbij u kunt denken aan mild, pittig of zeer pittig.<br />Hebt u speciale wensen? Dan staan onze mensen altijd klaar om u hierbij te helpen.<br /><br />U bent van harte welkom in ons restaurant om hier te dineren of mee te nemen naar huis. Beleef de authentiek Thaise keuken op z'n best bij Suvarnaphum Restaurant!<br /></div>


					
				</td>				<td class="wsite-multicol-col" style="width:43.616029822926%; padding:0 15px;">
					
						

<div class="wsite-spacer" style="height:50px;"></div>

<div><div class="wsite-image wsite-image-border-none " style="padding-top:10px;padding-bottom:10px;margin-left:0px;margin-right:0px;text-align:left">
<a>
<img src="/uploads/1/2/6/3/126368143/boeddha_1_orig.jpg" alt="Picture" style="width:392;max-width:100%" />
</a>
<div style="display:block;font-size:90%"></div>
</div></div>


					
				</td>			</tr>
		</tbody>
	</table>
</div></div></div>

<div class="wsite-spacer" style="height:50px;"></div>
			</div>
		</div>
      </div>

	</div>
</div>

</div>

    </div>

    <div class="footer-wrap">
        <div class="footer"><div class='wsite-elements wsite-footer'>Site powered by Weebly. Managed by <a href="https://www.hostmonster.com" target="_blank" rel="nofollow">Hostmonster</a></div></div>
    </div><!-- end footer-wrap -->
  </div><!-- /.wrapper -->

  <div id="navMobile" class="nav mobile-nav">
    <a class="hamburger" aria-label="Menu" href="#"><span></span></a>
    <ul class="wsite-menu-default">
    		<li id="active" class="wsite-menu-item-wrap">
    			<a
    						href="/"
    				class="wsite-menu-item"
    				>
    				Home
    			</a>
    			
    		</li>
    		<li id="pg355156789405947171" class="wsite-menu-item-wrap">
    			<a
    						href="/impressie.html"
    				class="wsite-menu-item"
    				>
    				Impressie
    			</a>
    			
    		</li>
    		<li id="pg959743226448925172" class="wsite-menu-item-wrap">
    			<a
    						href="/menu.html"
    				class="wsite-menu-item"
    				>
    				Menu
    			</a>
    			
    		</li>
    		<li id="pg914030071162666230" class="wsite-menu-item-wrap">
    			<a
    						href="/contact.html"
    				class="wsite-menu-item"
    				>
    				Contact
    			</a>
    			
    		</li>
    </ul>
  </div>

	<script type="text/javascript" src="/files/theme/plugins.js?1565969634"></script>
  <script type="text/javascript" src="/files/theme/custom.js?1565969634"></script>
    <div id="customer-accounts-app"></div>
    <script src="//cdn2.editmysite.com/js/site/main-customer-accounts-site.js?buildTime=1680891770"></script>

		<script type="text/javascript">
	var _gaq = _gaq || [];
	_gaq.push(['_setAccount', 'UA-7870337-1']);
	_gaq.push(['_setDomainName', 'none']);
	_gaq.push(['_setAllowLinker', true]);

	(function() {
		var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
		ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
		// NOTE: keep the [1] if you replace this code. Otherwise cookie banner scripts won't be first on the page
		var s = document.getElementsByTagName('script')[1]; s.parentNode.insertBefore(ga, s);
	})();

	_W.Analytics = _W.Analytics || {'trackers': {}};
	_W.Analytics.trackers.wGA = '_gaq';
</script>

<script type="text/javascript" async=1>
	// NOTE: keep the getElementsByTagName(o)**[1]** if you replace this code. Otherwise cookie banner scripts won't be first on the page
	;(function(p,l,o,w,i,n,g){if(!p[i]){p.GlobalSnowplowNamespace=p.GlobalSnowplowNamespace||[];
			p.GlobalSnowplowNamespace.push(i);p[i]=function(){(p[i].q=p[i].q||[]).push(arguments)
			};p[i].q=p[i].q||[];n=l.createElement(o);g=l.getElementsByTagName(o)[1];n.async=1;
			n.src=w;g.parentNode.insertBefore(n,g)}}(window,document,'script','//cdn2.editmysite.com/js/wsnbn/snowday262.js','snowday'));

	var r = [99, 104, 101, 99, 107, 111, 117, 116, 46, 40, 119, 101, 101, 98, 108, 121, 124, 101, 100, 105, 116, 109, 121, 115, 105, 116, 101, 41, 46, 99, 111, 109];
	var snPlObR = function(arr) {
		var s = '';
		for (var i = 0 ; i < arr.length ; i++){
			s = s + String.fromCharCode(arr[i]);
		}
		return s;
	};
	var s = snPlObR(r);

	var regEx = new RegExp(s);

	_W.Analytics = _W.Analytics || {'trackers': {}};
	_W.Analytics.trackers.wSP = 'snowday';
	_W.Analytics.user_id = '126368143';
	_W.Analytics.site_id = '856939515511031515';

	var drSegmentsTag = document.getElementById('drSegments');
	if (drSegmentsTag) {
		_W.Analytics.spContexts = _W.Analytics.spContexts || [];

		var segmentData = JSON.parse(drSegmentsTag.innerText);
		segmentData.forEach(function(test) {
			_W.Analytics.spContexts.push({
				schema: "iglu:com.weebly/context_ab_segment/jsonschema/1-0-0",
				data: {
					test_id: test.name,
					segment: test.variant,
				}
			});
		});
	}


	(function(app_id, ec_hostname, discover_root_domain) {
		var track = window[_W.Analytics.trackers.wSP];
		if (!track) return;
		track('newTracker', app_id, ec_hostname, {
			appId: app_id,
			post: true,
			platform: 'web',
			discoverRootDomain: discover_root_domain,
			cookieName: '_snow_',
			contexts: {
				webPage: true,
				performanceTiming: true,
				gaCookies: true
			},
			crossDomainLinker: function (linkElement) {
				return regEx.test(linkElement.href);
			},
			respectDoNotTrack: true
		});
		track('trackPageView', _W.Analytics.user_id+':'+_W.Analytics.site_id, _W.Analytics.spContexts);
		track('crossDomainLinker', function (linkElement) {
			return regEx.test(linkElement.href);
		});
	})(
		'_wn',
		'ec.editmysite.com',
		true
	);
</script>





<script>
	(function(jQuery) {
		try {
			if (jQuery) {
				jQuery('div.blog-social div.fb-like').attr('class', 'blog-social-item blog-fb-like');
				var $commentFrame = jQuery('#commentArea iframe');
				if ($commentFrame.length > 0) {
					var frameHeight = jQuery($commentFrame[0].contentWindow.document).height() + 50;
					$commentFrame.css('min-height', frameHeight + 'px');
				}
				if (jQuery('.product-button').length > 0){
					jQuery(document).ready(function(){
						jQuery('.product-button').parent().each(function(index, product){
							if(jQuery(product).attr('target') == 'paypal'){
								if (!jQuery(product).find('> [name="bn"]').length){
									jQuery('<input>').attr({
										type: 'hidden',
										name: 'bn',
										value: 'DragAndDropBuil_SP_EC'
									}).appendTo(product);
								}
							}
						});
					});
				}
			}
			else {
				// Prototype
				$$('div.blog-social div.fb-like').each(function(div) {
					div.className = 'blog-social-item blog-fb-like';
				});
				$$('#commentArea iframe').each(function(iframe) {
					iframe.style.minHeight = '410px';
				});
			}
		}
		catch(ex) {}
	})(window._W && _W.jQuery);
</script>

<script>
	window._W.isEUUser = false;
	window._W.showCookieToAll = "";
</script>


	</body>
</html>
