ul, ol, li, h1, h2, h3, h4, h5, h6, pre, form, body, html, div.paragraph, blockquote, fieldset, input { margin: 0; padding: 0; }
ul, ol, li, h1, h2, h3, h4, h5, h6, pre, form, body, html, p, blockquote, fieldset, input { margin: 0; padding: 0; }
 .wsite-form-field input[type='text'], .wsite-form-field input[type='email'], .wsite-form-field textarea, .wsite-form-field select, .wsite-form-field input[type='radio'], .wsite-form-field input[type='checkbox'], .wsite-com-product-option-groups input[type='text'], .wsite-com-product-option-groups input[type='email'], .wsite-com-product-option-groups textarea, .wsite-com-product-option-groups select, .wsite-com-product-option-groups input[type='radio'], .wsite-com-product-option-groups input[type='checkbox'] { -webkit-box-shadow: none; -moz-box-shadow: none; box-shadow: none; -webkit-appearance: none; -moz-appearance: none; appearance: none; text-shadow: none; }
 .wsite-form-field textarea, .wsite-com-product-option-groups textarea { resize: none; }
 @font-face { font-family: 'Birdseye'; src: url('theme/fonts/17c55b27-e9ab-43cd-b948-d49f97480d68.eot?#iefix?1643726521'); src: url('theme/fonts/17c55b27-e9ab-43cd-b948-d49f97480d68.eot?#iefix?1643726521') format('eot'), url('theme/fonts/2e3f5cb9-101f-46cf-a7b3-dfaa58261e03.woff2?1643726521') format('woff2'), url('theme/fonts/fa19948e-5e38-4909-b31e-41acd170d6f2.woff?1643726521') format('woff'), url('theme/fonts/6de0ce4d-9278-467b-b96f-c1f5f0a4c375.ttf?1643726521') format('truetype'), url('theme/fonts/9fd4ea0c-b19a-4b21-9fdf-37045707dd78.svg#9fd4ea0c-b19a-4b21-9fdf-37045707dd78?1643726521') format('svg'); font-weight: 100; font-style: normal; }
 @font-face { font-family: 'Birdseye'; src: url('theme/fonts/8b498c39-fabe-4789-bb81-5e37c9ecddd3.eot?#iefix?1643726521'); src: url('theme/fonts/8b498c39-fabe-4789-bb81-5e37c9ecddd3.eot?#iefix?1643726521') format('eot'), url('theme/fonts/1c6c1881-23c9-4d6a-a018-759d1c9ded15.woff2?1643726521') format('woff2'), url('theme/fonts/f0d655c5-a88a-49ad-bb29-f3b5cca41731.woff?1643726521') format('woff'), url('theme/fonts/3a561c83-40d4-4868-8255-e8455eb009c4.ttf?1643726521') format('truetype'), url('theme/fonts/3966f856-9dcf-48e7-88e7-7400f1b7d619.svg#3966f856-9dcf-48e7-88e7-7400f1b7d619?1643726521') format('svg'); font-weight: 100; font-style: italic; }
 @font-face { font-family: 'Birdseye'; src: url('theme/fonts/e9167238-3b3f-4813-a04a-a384394eed42.eot?#iefix?1643726521'); src: url('theme/fonts/e9167238-3b3f-4813-a04a-a384394eed42.eot?#iefix?1643726521') format('eot'), url('theme/fonts/2cd55546-ec00-4af9-aeca-4a3cd186da53.woff2?1643726521') format('woff2'), url('theme/fonts/1e9892c0-6927-4412-9874-1b82801ba47a.woff?1643726521') format('woff'), url('theme/fonts/46cf1067-688d-4aab-b0f7-bd942af6efd8.ttf?1643726521') format('truetype'), url('theme/fonts/52a192b1-bea5-4b48-879f-107f009b666f.svg#52a192b1-bea5-4b48-879f-107f009b666f?1643726521') format('svg'); font-weight: 500; font-style: normal; }
 @font-face { font-family: 'Birdseye'; src: url('theme/fonts/d1fddef1-d940-4904-8f6c-17e809462301.eot?#iefix?1643726521'); src: url('theme/fonts/d1fddef1-d940-4904-8f6c-17e809462301.eot?#iefix?1643726521') format('eot'), url('theme/fonts/7377dbe6-f11a-4a05-b33c-bc8ce1f60f84.woff2?1643726521') format('woff2'), url('theme/fonts/92b66dbd-4201-4ac2-a605-4d4ffc8705cc.woff?1643726521') format('woff'), url('theme/fonts/18839597-afa8-4f0b-9abb-4a30262d0da8.ttf?1643726521') format('truetype'), url('theme/fonts/1de7e6f4-9d4d-47e7-ab23-7d5cf10ab585.svg#1de7e6f4-9d4d-47e7-ab23-7d5cf10ab585?1643726521') format('svg'); font-weight: 500; font-style: italic; }
 @font-face { font-family: 'Birdseye'; src: url('theme/fonts/1a7c9181-cd24-4943-a9d9-d033189524e0.eot?#iefix?1643726521'); src: url('theme/fonts/1a7c9181-cd24-4943-a9d9-d033189524e0.eot?#iefix?1643726521') format('eot'), url('theme/fonts/627fbb5a-3bae-4cd9-b617-2f923e29d55e.woff2?1643726521') format('woff2'), url('theme/fonts/f26faddb-86cc-4477-a253-1e1287684336.woff?1643726521') format('woff'), url('theme/fonts/63a74598-733c-4d0c-bd91-b01bffcd6e69.ttf?1643726521') format('truetype'), url('theme/fonts/a89d6ad1-a04f-4a8f-b140-e55478dbea80.svg#a89d6ad1-a04f-4a8f-b140-e55478dbea80?1643726521') format('svg'); font-weight: 600; font-style: normal; }
 @font-face { font-family: 'Birdseye'; src: url('theme/fonts/77a9cdce-ea6a-4f94-95df-e6a54555545e.eot?#iefix?1643726521'); src: url('theme/fonts/77a9cdce-ea6a-4f94-95df-e6a54555545e.eot?#iefix?1643726521') format('eot'), url('theme/fonts/3f380a53-50ea-4a62-95c5-d5d8dba03ab8.woff2?1643726521') format('woff2'), url('theme/fonts/8344e877-560d-44d4-82eb-9822766676f9.woff?1643726521') format('woff'), url('theme/fonts/b28b01d9-78c5-46c6-a30d-9a62c8f407c5.ttf?1643726521') format('truetype'), url('theme/fonts/ed4d3c45-af64-4992-974b-c37cd12a9570.svg#ed4d3c45-af64-4992-974b-c37cd12a9570?1643726521') format('svg'); font-weight: 600; font-style: italic; }
 html { height: 100%; }
 body { width: 100%; height: 100%; background: rgba(0,0,0,0.05); color: #000000; font-family: 'Birdseye', sans-serif; font-size: 16px; font-weight: 500; -webkit-font-smoothing: antialiased; -moz-osx-font-smoothing: grayscale; }
 a { color: inherit; text-decoration: none; }
 a img, a:hover img { border: none; }
 h2 { color: #000000; font-family: 'Montserrat', sans-serif; font-size: 24px; font-weight: 700; line-height: 1.25; margin: 0 auto 30px; }
 div.paragraph, #wsite-search-list div.paragraph { font-family: 'Birdseye', sans-serif; font-size: 16px; font-weight: 500; line-height: 1.75; margin: 0 auto 30px; }
 p, #wsite-search-list p { font-family: 'Birdseye', sans-serif; font-size: 16px; font-weight: 500; line-height: 1.75; margin: 0 auto 30px; }
 div.paragraph a, #wsite-search-list div.paragraph a { color: inherit; font-weight: 600; text-decoration: underline; -webkit-transition: opacity 300ms ease-in-out; -moz-transition: opacity 300ms ease-in-out; -ms-transition: opacity 300ms ease-in-out; transition: opacity 300ms ease-in-out; }
 p a, #wsite-search-list p a { color: inherit; font-weight: 600; text-decoration: underline; -webkit-transition: opacity 300ms ease-in-out; -moz-transition: opacity 300ms ease-in-out; -ms-transition: opacity 300ms ease-in-out; transition: opacity 300ms ease-in-out; }
 div.paragraph a:hover, #wsite-search-list div.paragraph a:hover { opacity: 0.75; }
 p a:hover, #wsite-search-list p a:hover { opacity: 0.75; }
 blockquote { position: relative; padding: 1.5em 2.5em; background: rgba(0,0,0,0.05); font-family: 'Birdseye', sans-serif; font-size: 16px; font-weight: 500; line-height: 1.75; text-align: left; margin: 0 auto 30px; }
 blockquote:before { position: absolute; content: '\201C'; top: 0.75em; left: 0.5em; font-size: 2em; line-height: 1; font-weight: bold; }
 .splash-page .wsite-background, .wsite-header-section { background: url(theme/images/default-bg.jpg?1643726521) no-repeat top center; background-size: cover; }
 .wsite-header-section { height: 600px; }
 body.header-overlay-on .wsite-header-section:not(.wsite-section-bg-color):before { content: ''; display: block; position: absolute; top: 0; width: 100%; height: 60%; background: linear-gradient(to bottom,rgba(0,0,0,0.3) 0%,rgba(0,0,0,0.15) 40%,rgba(0,0,0,0) 100%); }
 .banner-wrap { position: relative; height: 100%; background: #000000; color: #ffffff; }
 .banner-wrap .container { padding: 80px 40px; }
 .banner-wrap .banner { text-align: center; -webkit-transition: opacity 500ms ease; -moz-transition: opacity 500ms ease; -ms-transition: opacity 500ms ease; transition: opacity 500ms ease; }
 .banner-wrap h2 { color: inherit; font-family: 'Birdseye', sans-serif; font-size: 80px; font-weight: 100; line-height: 1.15; margin: 15px auto; }
 .banner-wrap div.paragraph { color: inherit; font-family: 'Montserrat', sans-serif; font-size: 12px; font-weight: 700; line-height: 1.15; letter-spacing: 0.15em; margin: 15px auto; }
 .banner-wrap p { color: inherit; font-family: 'Montserrat', sans-serif; font-size: 12px; font-weight: 700; line-height: 1.15; letter-spacing: 0.15em; margin: 15px auto; }
 .container, .wsite-footer { position: relative; width: 100%; margin: 0 auto; box-sizing: border-box; }
 .main-wrap { width: 100%; background: #ffffff; }
 .main-wrap .container { padding: 60px 40px; }
 body.full-width-body-off .banner-wrap .container, body.full-width-body-off .main-wrap .container, body.full-width-body-off .wsite-footer { max-width: 1200px; margin: 0 auto; }
 .footer-wrap { width: 100%; font-size: 14px; }
 .footer-wrap .wsite-footer { padding: 60px 40px; }
 .footer-wrap h2, .footer-wrap div.paragraph, .footer-wrap blockquote { margin: 0 auto 20px; }
 .footer-wrap h2, .footer-wrap p, .footer-wrap blockquote { margin: 0 auto 20px; }
 .footer-wrap h2 { font-size: 20px; }
 .footer-wrap div.paragraph { font-size: 14px; }
 .footer-wrap p { font-size: 14px; }
 .footer-wrap blockquote { font-size: 14px; background: transparent; padding: 0 0 0 1em; }
 .footer-wrap blockquote:before { top: 0; left: 0; font-size: 1.5em; }
 .birdseye-header { position: fixed; top: 0; z-index: 12; width: 100%; max-width: 100%; padding: 20px 40px; color: #ffffff; border-color: #ffffff; box-sizing: border-box; -webkit-transition: background-color 300ms ease, color 260ms ease, padding 180ms ease; -moz-transition: background-color 300ms ease, color 260ms ease, padding 180ms ease; -ms-transition: background-color 300ms ease, color 260ms ease, padding 180ms ease; transition: background-color 300ms ease, color 260ms ease, padding 180ms ease; backface-visibility: hidden; -webkit-backface-visibility: hidden; }
 .birdseye-header .container { display: table; overflow-y: hidden; width: 100%; max-height: 80px; }
 .birdseye-header .hamburger { display: none; box-sizing: initial; }
 .birdseye-header .logo { display: table-cell; overflow-y: hidden; vertical-align: middle; }
 .birdseye-header .logo * { display: block; }
 .birdseye-header .logo a { margin-right: 30px; -webkit-transition: opacity 200ms ease; -moz-transition: opacity 200ms ease; -ms-transition: opacity 200ms ease; transition: opacity 200ms ease; }
 .birdseye-header .logo a:hover { opacity: .6; }
 .birdseye-header .logo #wsite-title { max-width: 400px; font-family: 'Montserrat', sans-serif; font-size: 30px; font-weight: 700; line-height: 1; text-transform: uppercase; letter-spacing: 0.03em; -webkit-transition: font-size 260ms ease; -moz-transition: font-size 260ms ease; -ms-transition: font-size 260ms ease; transition: font-size 260ms ease; }
 .birdseye-header .logo img { overflow: hidden; max-width: 200px; max-height: 40px; }
 .nav { display: table-cell; vertical-align: middle; }
 .nav ul { float: right; max-width: calc(100vw - 480px); overflow: hidden; }
 .nav li { display: inline-block; margin: 5px 5px 5px 0; }
 .nav .wsite-menu-item { display: block; padding: 12px 20px; border: 1px solid transparent; font-family: 'Montserrat', sans-serif; font-size: 12px; font-weight: 500; line-height: 1; letter-spacing: 0.05em; text-transform: uppercase; -webkit-transition: opacity 300ms ease; -moz-transition: opacity 300ms ease; -ms-transition: opacity 300ms ease; transition: opacity 300ms ease; }
 .nav li:not(.wsite-nav-cart)#active > .wsite-menu-item { border-color: inherit; }
 .nav li .wsite-menu-item:hover { opacity: 0.6; }
 .nav #wsite-nav-cart-a { padding-right: 0; }
 .nav #wsite-nav-cart-num { display: inline-block; min-width: 10px; padding: 2px 3px; margin-left: 2px; text-align: center; background: #ffffff; color: #000000; }
 .mobile-nav { display: none; }
 #wsite-menus > .wsite-menu-wrap > .wsite-menu .wsite-menu { margin: 0 -1px; }
 #wsite-menus .wsite-menu { position: relative; background: #ffffff; -webkit-box-shadow: inset 0px 0px 0px 1px #000000; -moz-box-shadow: inset 0px 0px 0px 1px #000000; -ms-box-shadow: inset 0px 0px 0px 1px #000000; box-shadow: inset 0px 0px 0px 1px #000000; }
 #wsite-menus .wsite-menu li a { background: transparent; color: #000000; font-family: 'Montserrat', sans-serif; font-size: 12px; font-weight: normal; line-height: normal; text-transform: uppercase; letter-spacing: 0.05em; border: none; }
 #wsite-menus .wsite-menu li a:hover { background: rgba(0,0,0,0.05); -webkit-transition: opacity 200ms ease; -moz-transition: opacity 200ms ease; -ms-transition: opacity 200ms ease; transition: opacity 200ms ease; }
 #wsite-menus .wsite-menu-arrow { display: none; }
 body.affix .birdseye-header { position: fixed; -webkit-box-shadow: 0px 1px 2px 0px rgba(0,0,0,0.05); -moz-box-shadow: 0px 1px 2px 0px rgba(0,0,0,0.05); -ms-box-shadow: 0px 1px 2px 0px rgba(0,0,0,0.05); box-shadow: 0px 1px 2px 0px rgba(0,0,0,0.05); padding: 10px 40px; }
 body.affix .birdseye-header .logo #wsite-title { font-size: 24px; }
 body.affix .birdseye-header .wsite-menu-item { padding: 10px 20px; }
 body.affix .birdseye-header, body.no-header-page .birdseye-header, body.splash-banner-page .birdseye-header { background: #ffffff; color: #000000; border-color: #000000; }
 body.affix .birdseye-header .nav #wsite-nav-cart-num, body.no-header-page .birdseye-header .nav #wsite-nav-cart-num, body.splash-banner-page .birdseye-header .nav #wsite-nav-cart-num { background: #000000; color: #ffffff; }
 body.affix .birdseye-header .hamburger span, body.affix .birdseye-header .hamburger span:before, body.affix .birdseye-header .hamburger span:after, body.no-header-page .birdseye-header .hamburger span, body.no-header-page .birdseye-header .hamburger span:before, body.no-header-page .birdseye-header .hamburger span:after, body.splash-banner-page .birdseye-header .hamburger span, body.splash-banner-page .birdseye-header .hamburger span:before, body.splash-banner-page .birdseye-header .hamburger span:after { background: #000000; }
 body.affix.alt-nav-on .birdseye-header, body.no-header-page.alt-nav-on .birdseye-header, body.splash-banner-page.alt-nav-on .birdseye-header { background: rgba(0,0,0,0.9); color: #ffffff; border-color: #ffffff; }
 body.affix.alt-nav-on .birdseye-header .nav #wsite-nav-cart-num, body.no-header-page.alt-nav-on .birdseye-header .nav #wsite-nav-cart-num, body.splash-banner-page.alt-nav-on .birdseye-header .nav #wsite-nav-cart-num { background: #ffffff; color: rgba(0,0,0,0.9); }
 body.affix.alt-nav-on .birdseye-header .hamburger span, body.affix.alt-nav-on .birdseye-header .hamburger span:before, body.affix.alt-nav-on .birdseye-header .hamburger span:after, body.no-header-page.alt-nav-on .birdseye-header .hamburger span, body.no-header-page.alt-nav-on .birdseye-header .hamburger span:before, body.no-header-page.alt-nav-on .birdseye-header .hamburger span:after, body.splash-banner-page.alt-nav-on .birdseye-header .hamburger span, body.splash-banner-page.alt-nav-on .birdseye-header .hamburger span:before, body.splash-banner-page.alt-nav-on .birdseye-header .hamburger span:after { background: #ffffff; }
 body.wsite-checkout-page .birdseye-header, body.wsite-native-mobile-editor .birdseye-header { position: absolute !important; }
 .no-header-page .main-wrap { padding-top: 80px; }
 body.splash-page .banner-wrap { display: table; width: 100%; height: 100vh; }
 body.splash-page .banner { display: table-cell; vertical-align: middle; text-align: center; }
 body.splash-page .footer-wrap { display: none; }
 body.splash-page .banner { display: none; }
 body.splash-page .birdseye-header { top: calc(50% - 132px); padding: 40px 80px; background: #ffffff; color: #000000; border-color: #000000; }
 body.splash-page .birdseye-header .container { height: 185px; max-height: none; }
 body.splash-page .birdseye-header .logo #wsite-title { font-size: 50px; }
 body.splash-page .birdseye-header .wsite-phone { font-family: 'Montserrat', sans-serif; font-size: 14px; color: rgba(0,0,0,0.6); padding-top: 20px; }
 body.splash-page .birdseye-header .nav .wsite-menu-item { font-size: 14px; }
 body.splash-page .birdseye-header li#active > .wsite-menu-item { border-color: transparent; }
 body.splash-page .birdseye-header .nav #wsite-nav-cart-num { background: #000000; color: #ffffff; }
 body.splash-page.alt-nav-on .birdseye-header { background: #000000; color: #ffffff; border-color: #ffffff; }
 body.splash-page.alt-nav-on .birdseye-header .wsite-phone { color: rgba(255,255,255,0.6); }
 body.splash-page.alt-nav-on .birdseye-header .nav #wsite-nav-cart-num { background: #ffffff; color: #000000; }
 body:not(.wsite-editor) .logo, body:not(.wsite-editor) .desktop-nav { opacity: 0; -webkit-transition: opacity 600ms ease-in 300ms; -moz-transition: opacity 600ms ease-in 300ms; -ms-transition: opacity 600ms ease-in 300ms; transition: opacity 600ms ease-in 300ms; }
 body:not(.wsite-editor).fade-in .logo, body:not(.wsite-editor).fade-in .desktop-nav { opacity: 1; }
 ::-webkit-input-placeholder, :-moz-placeholder, ::-moz-placeholder, :-ms-input-placeholder { color: rgba(0,0,0,0.4); }
 .wsite-form-field .wsite-form-input, .wsite-form-field .wsite-search-element-input, .wsite-form-field .form-select, .wsite-form-field .wsite-form-field select, .wsite-form-field .wsite-com-product-option-groups select, .wsite-form-field .form-radio-container, .wsite-form-field input[type='radio'], .wsite-form-field input[type='checkbox'], .wsite-com-product-option-groups .wsite-form-input, .wsite-com-product-option-groups .wsite-search-element-input, .wsite-com-product-option-groups .form-select, .wsite-com-product-option-groups .wsite-form-field select, .wsite-com-product-option-groups .wsite-com-product-option-groups select, .wsite-com-product-option-groups .form-radio-container, .wsite-com-product-option-groups input[type='radio'], .wsite-com-product-option-groups input[type='checkbox'] { color: #000000; font-family: 'Montserrat', sans-serif; font-size: 14px; font-weight: normal; line-height: 1; border-radius: 0; -webkit-transition: all 300ms ease; -moz-transition: all 300ms ease; -ms-transition: all 300ms ease; transition: all 300ms ease; }
 .wsite-form-input, .wsite-search-element-input, .form-select, .wsite-form-field select, .wsite-com-product-option-groups select { color: #000000; height: auto; max-width: 370px; padding: 10px 20px !important; margin-bottom: 10px; background: transparent; border: 1px solid rgba(0,0,0,0.4); }
 .wsite-form-input:hover, .wsite-form-input:focus, .wsite-form-input--focus, .wsite-search-element-input:hover, .wsite-search-element-input:focus, .form-select:hover, .form-select:focus, .wsite-form-field select:hover, .wsite-form-field select:focus, .wsite-com-product-option-groups select:hover, .wsite-com-product-option-groups select:focus { background-color: rgba(0,0,0,0.05); border-color: #000000; }
 .form-select, .wsite-form-field select, .wsite-com-product-option-groups select { text-indent: 0.01px; text-overflow: ''; height: 40px; background: transparent url(theme/images/select-dropdown.svg?1643726521) 97% center no-repeat; }
 .wsite-form-field input[type='radio'], .wsite-form-field input[type='checkbox'], .wsite-com-product-option-groups input[type='radio'], .wsite-com-product-option-groups input[type='checkbox'] { width: 20px; height: 20px; border: 1px solid rgba(0,0,0,0.4) !important; }
 .wsite-form-field input[type='radio']:hover, .wsite-form-field input[type='radio']:checked, .wsite-form-field input[type='checkbox']:hover, .wsite-form-field input[type='checkbox']:checked, .wsite-com-product-option-groups input[type='radio']:hover, .wsite-com-product-option-groups input[type='radio']:checked, .wsite-com-product-option-groups input[type='checkbox']:hover, .wsite-com-product-option-groups input[type='checkbox']:checked { border-color: #000000 !important; }
 .wsite-form-field input[type='radio'], .wsite-com-product-option-groups input[type='radio'] { border-radius: 100%; }
 .wsite-form-field input[type='radio']:after, .wsite-com-product-option-groups input[type='radio']:after { display: block; border-radius: 100%; box-sizing: border-box; content: ''; }
 .wsite-form-field input[type='radio']:checked:after, .wsite-com-product-option-groups input[type='radio']:checked:after { background: #ffffff; border: 4px solid #000000; width: 18px; height: 18px; }
 .wsite-form-field input[type='checkbox']:after, .wsite-com-product-option-groups input[type='checkbox']:after { position: relative; top: 2px; left: 6px; width: 4px; height: 8px; border: solid #ffffff; border-width: 0 2px 2px 0; -webkit-transform: rotate(45deg); -moz-transform: rotate(45deg); -ms-transform: rotate(45deg); -o-transform: rotate(45deg); transform: rotate(45deg); }
 .wsite-form-field input[type='checkbox']:checked, .wsite-com-product-option-groups input[type='checkbox']:checked { background: #000000; }
 .wsite-form-field input[type='checkbox']:checked:after, .wsite-com-product-option-groups input[type='checkbox']:checked:after { display: block; content: ' '; }
 .wsite-search-element { margin-bottom: 10px; }
 .wsite-search-element .wsite-search-element-input { margin-bottom: 0; }
 .wsite-form-label { display: inline-block; padding: 0; color: #000000; font-family: 'Montserrat', sans-serif; font-size: 12px; text-transform: uppercase; font-weight: normal; line-height: 1; margin-bottom: 10px; }
 .wsite-form-sublabel { display: none; }
 .wsite-form-radio-container { margin-bottom: 15px; }
 .formlist, .wsite-editor .formlist { min-height: inherit; }
 .wsite-form-container .form-input-error { border: 1px solid red !important; }
 .form-field-error .wsite-form-radio-container { border: none; }
 .wsite-button { display: inline-block; height: auto; padding: 0; background-image: none !important; background-color: transparent; color: #000000 !important; border: 1px solid #000000 !important; -webkit-transition: all 100ms ease-in-out; -moz-transition: all 100ms ease-in-out; -ms-transition: all 100ms ease-in-out; transition: all 100ms ease-in-out; }
 .wsite-button:hover { background-color: rgba(0,0,0,0.05); }
 .wsite-button .wsite-button-inner { display: inline-block; height: auto; padding: 14px 30px; background: transparent; background-image: none !important; color: inherit !important; letter-spacing: 0.03em; font-family: 'Montserrat', sans-serif; font-size: 12px; line-height: 1; text-transform: uppercase; }
 .wsite-button-large { color: #ffffff !important; border: 1px solid #ffffff !important; }
 .wsite-button-large:hover { background-color: rgba(255,255,255,0.2) !important; }
 .wsite-button-highlight, #wsite-com-product-add-to-cart.wsite-button-highlight { background-color: #000000 !important; color: #ffffff !important; border: 1px solid #000000 !important; }
 .wsite-button-highlight:hover, #wsite-com-product-add-to-cart.wsite-button-highlight:hover { background-color: transparent !important; color: #000000 !important; }
 .wsite-button-highlight.wsite-button-large:not(.wsite-buy-button), #wsite-com-product-add-to-cart.wsite-button-highlight.wsite-button-large:not(.wsite-buy-button) { background-color: #ffffff !important; color: #000000 !important; border: 1px solid #ffffff !important; }
 .wsite-button-highlight.wsite-button-large:not(.wsite-buy-button):hover, #wsite-com-product-add-to-cart.wsite-button-highlight.wsite-button-large:not(.wsite-buy-button):hover { background-color: transparent !important; color: #ffffff !important; }
 .wsite-social { white-space: normal; }
 .wsite-social-item { display: inline-block; font-size: 20px; margin: 5px; -webkit-transition: all 300ms ease; -moz-transition: all 300ms ease; -ms-transition: all 300ms ease; transition: all 300ms ease; }
 .wsite-social-item:first-child { margin-left: 0; }
 .wsite-social-item:last-child { margin-right: 0; }
 .wsite-social-item:hover { color: rgba(0,0,0,0.6); }
 .imageGallery .galleryImageHolder .fullImageGalleryCaption .galleryCaptionHolderInnerBg, .imageGallery .galleryImageHolder .partialImageGalleryCaption .galleryCaptionHolderInnerBg { opacity: 1; bottom: 0; background: rgba(0,0,0,0.2); -webkit-transition: all 260ms ease; -moz-transition: all 260ms ease; -ms-transition: all 260ms ease; transition: all 260ms ease; }
 .imageGallery .galleryImageHolder:hover .galleryCaptionHolderInnerBg { background: rgba(0,0,0,0.6); }
 .imageGallery .galleryImageHolder .galleryCaptionInnerText { color: #ffffff; letter-spacing: normal; text-shadow: none; font-family: 'Birdseye', sans-serif; font-size: 14px; font-weight: 500; line-height: 1.1; }
 .wsite-image img { margin-bottom: 10px; }
 .fancybox-overlay { background: rgba(255,255,255,0.9); }
 .fancybox-skin { background: transparent !important; -webkit-box-shadow: none !important; -moz-box-shadow: none !important; -ms-box-shadow: none !important; box-shadow: none !important; }
 .fancybox-title { color: #000000; font-family: 'Birdseye', sans-serif; font-size: 14px; font-weight: normal; line-height: normal; }
 .fancybox-close, .fancybox-next span, .fancybox-prev span { background: none !important; width: auto; height: auto; }
 .fancybox-close:before, .fancybox-next span:before, .fancybox-prev span:before { color: #ffffff !important; font-family: 'Birdseye', sans-serif; font-size: 45px; font-weight: 400; line-height: 0.75em; -webkit-transition: all 300ms ease; -moz-transition: all 300ms ease; -ms-transition: all 300ms ease; transition: all 300ms ease; }
 .fancybox-close:hover:before, .fancybox-next:hover span:before, .fancybox-prev:hover span:before { color: rgba(255,255,255,0.8) !important; }
 .fancybox-prev span:before { position: relative; left: -10px; content: '\3008'; }
 .fancybox-next span:before { position: relative; right: -10px; content: '\3009'; }
 .fancybox-close { top: 20px; right: 20px; }
 .fancybox-close:before { content: '\00D7'; }
 #wsite-com-store .wsite-com-category-subcategory-image-wrap { height: 100%; border: none; }
 #wsite-com-store .wsite-com-category-subcategory-name { top: 0; }
 #wsite-com-store .wsite-com-category-subcategory-name-bg { background-color: rgba(0,0,0,0.2); background-image: linear-gradient(top,rgba(0,0,0,0.2),rgba(0,0,0,0.4)); background-image: -webkit-linear-gradient(top,rgba(0,0,0,0.2),rgba(0,0,0,0.4)); background-image: -moz-linear-gradient(top,rgba(0,0,0,0.2),rgba(0,0,0,0.4)); background-image: -ms-linear-gradient(top,rgba(0,0,0,0.2),rgba(0,0,0,0.4)); background-image: -o-linear-gradient(top,rgba(0,0,0,0.2),rgba(0,0,0,0.4)); }
 #wsite-com-store .wsite-com-category-subcategory-name-text { position: absolute; bottom: 0; width: 100%; background: none; box-sizing: border-box; text-shadow: none; font-weight: 400; }
 #wsite-com-store #wsite-com-product-title { font-weight: inherit; }
 #wsite-com-store .wsite-com-category-subcategory-link .wsite-com-category-subcategory-image-wrap, #wsite-com-store .wsite-com-category-product-link .wsite-com-category-product-image-wrap, #wsite-com-store .wsite-com-category-product-link-featured .wsite-com-category-product-featured-image-wrap { opacity: 1; -webkit-transition: all 300ms ease; -moz-transition: all 300ms ease; -ms-transition: all 300ms ease; transition: all 300ms ease; }
 #wsite-com-store .wsite-com-category-subcategory-link:hover .wsite-com-category-subcategory-image-wrap, #wsite-com-store .wsite-com-category-product-link:hover .wsite-com-category-product-image-wrap, #wsite-com-store .wsite-com-category-product-link-featured:hover .wsite-com-category-product-featured-image-wrap { opacity: .7; }
 #wsite-com-store #wsite-com-hierarchy ul { font-size: 16px; }
 #wsite-com-store #wsite-com-hierarchy ul .wsite-link-unselected { color: #000000; }
 #wsite-com-store #wsite-com-hierarchy ul .wsite-link-unselected:hover { color: rgba(0,0,0,0.4); }
 .wsite-product { border-radius: 0; box-shadow: none; }
 h2#wsite-com-product-title { display: block; clear: both; font-weight: 400; }
 .wsite-com-product-title { font-weight: 400; }
 #wsite-com-breadcrumbs.wsite-com-product-breadcrumbs, #wsite-com-breadcrumbs.wsite-com-category-breadcrumbs { padding-bottom: 25px; }
 .wsite-com-category-product-group .wsite-com-category-product-wrap, .wsite-com-category-product-featured-group .wsite-com-category-product-wrap, .wsite-com-category-product-featured-group .wsite-com-category-product-featured-wrap, .wsite-com-category-subcategory-group .wsite-com-category-subcategory-wrap { font-size: 1em; }
 #wsite-com-product-info { float: left; width: 45%; margin-left: 60px; }
 .wsite-product-button-wrap { text-align: left; }
 #wsite-mini-cart { border-radius: 0; border-color: #000000 !important; padding: 5px !important; margin-top: 3px; top: auto !important; }
 #wsite-mini-cart:before, #wsite-mini-cart:after { display: none !important; }
 #wsite-mini-cart .wsite-product-list { display: block; max-height: 290px; overflow-y: scroll; }
 #wsite-mini-cart .wsite-product-list li { display: table; }
 #wsite-mini-cart .wsite-product-image { padding: 10px; }
 #wsite-mini-cart .wsite-product-list .wsite-list-image-container { margin: 0; }
 #wsite-mini-cart .wsite-items-right { width: 22%; }
 #wsite-mini-cart .wsite-items-quantity { width: 10%; text-align: center; }
 #wsite-mini-cart .wsite-vertical-align { padding-top: 10px; padding-bottom: 10px; vertical-align: top; }
 #wsite-mini-cart .wsite-product-list .wsite-product-price, #wsite-mini-cart .wsite-items-quantity, #wsite-mini-cart .wsite-name-header, #wsite-mini-cart .wsite-subtotal-wrapper, #wsite-mini-cart .wsite-subtotal-wrapper * { color: #000000; font-family: 'Montserrat', sans-serif; font-size: 14px; font-weight: 500; text-transform: uppercase; line-height: 1.25; }
 #wsite-mini-cart .wsite-product-list .wsite-product-price { padding-right: 0; }
 #wsite-mini-cart .wsite-product-option { font-family: 'Birdseye', sans-serif; font-size: 12px; font-weight: 500; }
 #wsite-mini-cart .wsite-subtotal-wrapper { vertical-align: middle; }
 #wsite-mini-cart .wsite-subtotal-wrapper span { font-family: 'Montserrat', sans-serif; font-size: 13px !important; margin-right: 5px; }
 #wsite-mini-cart .wsite-subtotal-wrapper span.wsite-price { font-size: 14px !important; font-weight: 900; }
 #wsite-mini-cart .wsite-remove-button { background: none !important; font-family: 'Montserrat', sans-serif; height: auto; width: 100%; clear: both; float: none; cursor: pointer; color: #DD5857; font-size: 12px; text-align: right; margin-top: 0; margin-right: 0; }
 #blogTable .blog-post .blog-header h2.blog-title { font-size: 20px; font-weight: 500; margin-bottom: 10px !important; }
 #blogTable .blog-post .blog-separator { margin: 0 auto 30px; border: none; }
 #blogTable .blog-sidebar { width: 250px; }
 #blogTable .blog-sidebar h2 { font-size: 18px; font-weight: 500; margin-bottom: 10px; }
 #blogTable .blog-sidebar div.paragraph { font-size: 14px; }
 #blogTable .blog-sidebar p { font-size: 14px; }
 #blogTable #commentArea #commentAreaTitle, #blogTable #commentArea #commentReplyTitle, #blogTable #commentArea .blogCommentText div.paragraph, #blogTable #commentArea .blog-sidebar h2 { padding: 0; font-family: inherit; }
 #blogTable #commentArea #commentAreaTitle, #blogTable #commentArea #commentReplyTitle, #blogTable #commentArea .blogCommentText p, #blogTable #commentArea .blog-sidebar h2 { padding: 0; font-family: inherit; }
 #blogTable .blogCommentWrap { padding-top: 20px; border-top: 1px solid rgba(0,0,0,0.4); background: none; }
 #blogTable .blogCommentWrap .blogCommentAuthor, #blogTable .blogCommentWrap .blogCommentHeading, #blogTable .blogCommentWrap .blogCommentHeadingInner { background: none !important; }
 #blogTable .blogCommentWrap .blogCommentAuthor { margin-bottom: 10px; }
 #blogTable .blogCommentWrap .blogCommentAuthor span.name, #blogTable .blogCommentWrap .blogCommentAuthor span.email { color: #000000 !important; float: none; line-height: 1; }
 #blogTable .blogCommentWrap .blogCommentHeading { padding: 0; margin-bottom: 20px; }
 #blogTable .blogCommentWrap .blogCommentHeading .blogCommentHeadingInner { height: auto; }
 #blogTable .blogCommentWrap .blogCommentHeading .blogCommentAuthor, #blogTable .blogCommentWrap .blogCommentHeading .blogCommentDate { float: none; text-align: left; height: auto; font-family: 'Montserrat', sans-serif; font-weight: normal; line-height: 1; letter-spacing: 0.03em; padding: 0; }
 #blogTable .blogCommentWrap .blogCommentHeading .blogCommentAuthor { text-transform: uppercase; }
 #blogTable .blogCommentWrap .blogCommentHeading .blogCommentDate { color: #333; }
 #blogTable .blogCommentWrap .blogCommentText { padding: 0; }
 #blogTable .blogCommentWrap .blogCommentText div.paragraph { color: #000000; font-size: 12px; }
 #blogTable .blogCommentWrap .blogCommentText p { color: #000000; font-size: 12px; }
 .blogCommentReplyWrapper iframe { height: 560px !important; }
 #commentPostDiv .field input[type=text], #commentPostDiv .field textarea { height: auto; padding: 8px 12px; background: transparent; box-sizing: border-box; -webkit-transition: all 300ms ease; -moz-transition: all 300ms ease; -ms-transition: all 300ms ease; transition: all 300ms ease; }
 #commentPostDiv .field input[type=text]:focus, #commentPostDiv .field textarea:focus { background-color: rgba(0,0,0,0.05); border: 1px solid rgba(0,0,0,0.4); }
 .blogCommentSubreplyWrapper div.iframeWrapper { background: none; border: none; }
 .blog-button { height: auto; padding: 10px 20px; background-image: none; background-color: rgba(0,0,0,0.6); color: #ffffff; font-family: 'Montserrat', sans-serif; font-size: 12px; line-height: 1; text-transform: uppercase; -webkit-transition: all 300ms ease; -moz-transition: all 300ms ease; -ms-transition: all 300ms ease; transition: all 300ms ease; }
 .blog-button:hover { background-color: rgba(0,0,0,0.2); }
 .blog-button span { background: none; }
 @media screen and (max-width: 992px) {
 font[size="1"] { font-size: 50% !important; }
 font[size="2"] { font-size: 75% !important; }
 font[size="3"] { font-size: 125% !important; }
 font[size="4"] { font-size: 150% !important; }
 font[size="5"] { font-size: 175% !important; }
 font[size="6"] { font-size: 200% !important; }
 font[size="7"] { font-size: 250% !important; }
 .container, .wsite-footer { overflow: hidden; }
 .birdseye-header { top: 0; left: 0; padding: 5px 20px !important; min-height: 50px; }
 .birdseye-header .birdseye-header, .birdseye-header .logo, .birdseye-header .logo img { max-height: 40px; }
 .birdseye-header .logo { overflow: hidden; padding-right: 25px; }
 .birdseye-header .logo a { margin-left: 0; margin-right: 0; font-size: 1.1em; line-height: 1.4em; }
 .birdseye-header .logo #wsite-title { display: block; max-width: 100%; font-size: 1.1em !important; line-height: 1.4em !important; }
 .birdseye-header .container { min-height: 40px; max-height: inherit; }
 .birdseye-header .hamburger { display: table-cell; vertical-align: middle; }
 body.cart-full #wsite-mini-cart { display: block !important; }
 body.cart-full .wsite-footer { padding-bottom: 70px; }
 body.nav-open .mobile-nav { padding: 50px 0; max-height: 100vh; }
 body.nav-open .birdseye-header label.hamburger span { position: relative; background: transparent; }
 body.nav-open .birdseye-header label.hamburger span:before { top: 1px; -webkit-transform: rotate(45deg); -moz-transform: rotate(45deg); -ms-transform: rotate(45deg); transform: rotate(45deg); }
 body.nav-open .birdseye-header label.hamburger span:after { top: -1px; -webkit-transform: rotate(135deg); -moz-transform: rotate(135deg); -ms-transform: rotate(135deg); transform: rotate(135deg); }
 body.splash-page.nav-open .wrapper .main-wrap { position: relative; }
 .hamburger { position: absolute; top: -5px; right: -10px; width: 30px; height: 30px; padding: 10px; cursor: pointer; -webkit-transition: all 300ms ease-in-out; -moz-transition: all 300ms ease-in-out; -ms-transition: all 300ms ease-in-out; transition: all 300ms ease-in-out; }
 .hamburger span, .hamburger span:before, .hamburger span:after { position: relative; display: block; width: 22px; height: 2px; background: #ffffff; content: ''; -webkit-transition: all 200ms ease-in-out; -moz-transition: all 200ms ease-in-out; -ms-transition: all 200ms ease-in-out; transition: all 200ms ease-in-out; }
 .hamburger span { top: 9px; left: 4px; margin: 5px 0; }
 .hamburger span:before { top: -8px; }
 .hamburger span:after { bottom: -6px; }
 .desktop-nav { display: none; }
 .mobile-nav { position: fixed; top: 0; left: 0; z-index: 12; display: block; overflow-x: hidden; overflow-y: auto; width: 100%; height: 100%; max-height: 0; padding: 0; background: #ffffff; box-sizing: border-box; -webkit-transition: all 300ms cubic-bezier(0, 0.085, 0.68, 0.53); -moz-transition: all 300ms cubic-bezier(0, 0.085, 0.68, 0.53); -ms-transition: all 300ms cubic-bezier(0, 0.085, 0.68, 0.53); transition: all 300ms cubic-bezier(0, 0.085, 0.68, 0.53); }
 .mobile-nav .hamburger { top: 0; right: 10px; }
 .mobile-nav .hamburger span { background: transparent; }
 .mobile-nav .hamburger span:before { top: 1px; background: #000000; -webkit-transform: rotate(45deg); -moz-transform: rotate(45deg); -ms-transform: rotate(45deg); transform: rotate(45deg); }
 .mobile-nav .hamburger span:after { top: -1px; background: #000000; -webkit-transform: rotate(135deg); -moz-transform: rotate(135deg); -ms-transform: rotate(135deg); transform: rotate(135deg); }
 .mobile-nav ul { float: none; height: auto; max-width: none; }
 .mobile-nav li { position: relative; display: block !important; margin: 0; border: none; text-align: center; }
 .mobile-nav li .wsite-menu-link-styles { position: relative; padding: 10px 0; border: none; }
 .mobile-nav li > a.wsite-menu-item { position: relative; padding: 10px 0; border: none; }
 .mobile-nav li > a.wsite-menu-subitem { display: block; position: relative; padding: 10px 0; color: rgba(0,0,0,0.6); border: none; font-size: 14px; font-weight: 400; line-height: 1; -webkit-transition: all 300ms ease; -moz-transition: all 300ms ease; -ms-transition: all 300ms ease; transition: all 300ms ease; }
 .mobile-nav li .wsite-menu-wrap { display: block !important; overflow: hidden; max-height: 0; -webkit-transition: all 500ms ease-in-out 250ms; -moz-transition: all 500ms ease-in-out 250ms; -ms-transition: all 500ms ease-in-out 250ms; transition: all 500ms ease-in-out 250ms; }
 .mobile-nav li .wsite-menu-wrap li.wsite-nav-current > a.wsite-menu-subitem { background: rgba(0,0,0,0.05); border: none; }
 .mobile-nav li .wsite-menu-wrap .wsite-menu-arrow { display: none; }
 .mobile-nav li.wsite-menu-item-wrap#active > a.wsite-menu-item, .mobile-nav li.wsite-menu-item-wrap > a.wsite-menu-item:hover, .mobile-nav li.wsite-menu-subitem-wrap > a.wsite-menu-subitem:hover { background: rgba(0,0,0,0.05); border: none; }
 .mobile-nav li.has-submenu > span.icon-caret { position: absolute; top: 0; right: 0; display: block; width: 20px; height: 20px; padding: 5px 20px; cursor: pointer; -webkit-transition: all 300ms ease-in-out; -moz-transition: all 300ms ease-in-out; -ms-transition: all 300ms ease-in-out; transition: all 300ms ease-in-out; }
 .mobile-nav li.has-submenu > span.icon-caret:before { position: relative; display: block; color: #000000; font-size: 24px; content: '\203A'; -webkit-transform: rotate(90deg); -moz-transform: rotate(90deg); -ms-transform: rotate(90deg); transform: rotate(90deg); }
 .mobile-nav li.has-submenu .wsite-menu-wrap.open { max-height: 1000px; }
 .mobile-nav li.wsite-nav-more { display: none !important; }
 .banner-wrap .container { padding: 60px 20px; word-wrap: break-word; }
 .banner-wrap .container h2 { font-size: 50px; }
 .main-wrap .container { padding: 30px 20px; }
 .footer-wrap .wsite-footer { width: 100%; padding: 30px 20px; box-sizing: border-box; }
 #wsite-mini-cart { position: fixed !important; top: initial !important; bottom: 0px; left: 0 !important; z-index: 9; width: 100%; box-sizing: border-box; border: none; border-radius: 0; backface-visibility: hidden; -webkit-backface-visibility: hidden; -webkit-transition: all 300ms ease-in-out; -moz-transition: all 300ms ease-in-out; -ms-transition: all 300ms ease-in-out; transition: all 300ms ease-in-out; }
 #wsite-mini-cart .arrow-top:before, #wsite-mini-cart .arrow-top:after, #wsite-mini-cart .arrow-left:before, #wsite-mini-cart .arrow-left:after { border: none !important; }
 #wsite-mini-cart .wsite-product-list { display: none; }
 .no-header-page .main-wrap { padding-top: 50px; }
 .no-header-page .birdseye-header { padding: 5px 20px; }
 .splash-page .birdseye-header { padding: 5px 20px; }
 .splash-page .hamburger { right: 20px; top: 10px; }
 .splash-page h2 { font-size: 9vw; }
 .splash-page div.paragraph { font-size: 16px; }
 .splash-page p { font-size: 16px; }
 }
 @media screen and (max-width: 767px) {
 font[size="1"] { font-size: 50% !important; }
 font[size="2"] { font-size: 75% !important; }
 font[size="3"] { font-size: 110% !important; }
 font[size="4"] { font-size: 120% !important; }
 font[size="5"] { font-size: 130% !important; }
 font[size="6"] { font-size: 140% !important; }
 font[size="7"] { font-size: 150% !important; }
 .wsite-section { height: auto !important; }
 .banner-wrap .banner h2 { font-size: 9vw; }
 .imageGallery > div { width: 49.95% !important; }
 td.wsite-multicol-col { float: none; display: block; width: 100% !important; box-sizing: border-box; }
 #blogTable td { float: none; display: block; clear: both; width: 100%; margin: 0; padding: 0; }
 #blogTable td.blog-sidebar { width: 100%; }
 #blogTable td.blog-sidebar div.paragraph { margin-bottom: 0; }
 #blogTable td.blog-sidebar p { margin-bottom: 0; }
 #blogTable td .blog-body { float: none !important; }
 #blogTable td .column-blog { width: 100%; float: none; }
 #blogTable td .blog-sidebar-separator { padding: 0; }
 #wsite-com-store .wsite-com-category-subcategory-group .wsite-com-column, #wsite-com-store .wsite-com-category-product-featured-group .wsite-com-column, #wsite-com-store .wsite-com-category-product-group .wsite-com-column { float: left; width: 50% !important; }
 #wsite-com-store .wsite-com-sidebar { position: relative; float: none !important; z-index: 6; width: 100%; min-height: 35px; margin: 0 auto 15px; padding: 0; text-align: center; }
 #wsite-com-store .wsite-com-sidebar:before { display: block; width: 100%; padding: 10px 18px; box-sizing: border-box; text-align: center; text-transform: uppercase; content: 'VIEW ALL CATEGORIES\00a0\00a0\25be'; font-weight: 700; cursor: pointer; }
 #wsite-com-store .wsite-com-sidebar #wsite-com-hierarchy { position: relative; display: block; overflow: hidden; width: 100%; max-height: 0px; padding: 0; background: #ffffff; box-sizing: border-box; -webkit-transition: all 300ms ease-in-out; -moz-transition: all 300ms ease-in-out; -ms-transition: all 300ms ease-in-out; transition: all 300ms ease-in-out; cursor: default !important; }
 #wsite-com-store .wsite-com-sidebar #wsite-com-hierarchy > ul { width: 100%; padding: 0; }
 #wsite-com-store .wsite-com-sidebar #wsite-com-hierarchy > ul li { margin-bottom: 15px; }
 #wsite-com-store .wsite-com-sidebar.sidebar-expanded { cursor: default !important; }
 #wsite-com-store .wsite-com-sidebar.sidebar-expanded:before { content: 'CLOSE\00a0\00a0\25b4'; }
 #wsite-com-store .wsite-com-sidebar.sidebar-expanded #wsite-com-hierarchy { max-height: 800vh; padding: 10px 0; }
 #wsite-com-store .wsite-com-content-with-sidebar { margin-left: 0; }
 div.wsite-product-image-wrap, .wsite-product .wsite-product-top { width: 100% !important; }
 .wsite-product .wsite-product-button-wrap { width: auto; }
 #wsite-com-product-images { float: none; width: 100%; margin-bottom: 20px; }
 #wsite-com-product-info { width: 100%; margin-left: 0; }
 #wsite-com-product-images-strip .wsite-com-product-images-secondary-outer { margin-bottom: 10px; }
 #wsite-search-sidebar { position: relative; z-index: 6; overflow-y: hidden; width: 100%; max-height: 35px; padding: 0; box-sizing: border-box; -webkit-transition: all 500ms ease-in-out; -moz-transition: all 500ms ease-in-out; -ms-transition: all 500ms ease-in-out; transition: all 500ms ease-in-out; }
 #wsite-search-sidebar:before { display: block; width: 100%; padding: 10px 18px; box-sizing: border-box; text-align: center; text-transform: uppercase; content: 'VIEW SEARCH FILTERS\00a0\00a0\25be'; font-weight: 700; cursor: pointer; }
 #wsite-search-sidebar.sidebar-expanded { max-height: 1000px; cursor: default !important; }
 #wsite-search-sidebar.sidebar-expanded:before { content: 'CLOSE\00a0\00a0\25b4'; }
 #wsite-search-sidebar .wsite-search-facet-price input { width: 100%; margin: 10px 0; padding: 6px !important; }
 #wsite-search-header h2 { width: 100%; margin-bottom: 10px; font-size: 1.6em; }
 #wsite-search-form-container { float: none; width: 100%; }
 #wsite-search-query { padding: 2px 10px; }
 #wsite-search-results { width: 100%; }
 #wsite-search-product-results .wsite-search-product-result { width: 100%; padding-right: 0; }
 }
 @media screen and (max-width: 480px) {
 #wsite-com-checkout-list .wsite-com-checkout-item-image, #wsite-com-checkout-summary-list .wsite-com-checkout-item-image { display: none; }
 #wsite-com-checkout-list tbody td:first-child, #wsite-com-checkout-summary-list tbody td:first-child { width: 0; padding: 0; }
 #wsite-com-checkout-list .wsite-com-checkout-item-details-inner, #wsite-com-checkout-summary-list .wsite-com-checkout-item-details-inner { padding-left: 0; }
 }

div.paragraph ul, div.paragraph ol { padding-left: 3em !important; margin: 5px 0 !important; }
div.paragraph li { padding-left: 5px !important; margin: 3px 0 0 !important; }
div.paragraph ul, div.paragraph ul li { list-style: disc outside !important; }
div.paragraph ol, div.paragraph ol li { list-style: decimal outside !important; }
